﻿// Copyright (c) AlphaSierraPapa for the SharpDevelop Team (for details please see \doc\copyright.txt)
// This code is distributed under the GNU LGPL (for details please see \doc\license.txt)

using System;
using ICSharpCode.FormsDesigner;
using ICSharpCode.PythonBinding;
using ICSharpCode.Scripting.Tests.Utils;
using ICSharpCode.SharpDevelop.Dom;
using NUnit.Framework;
using PythonBinding.Tests.Utils;

namespace PythonBinding.Tests.Designer
{
	/// <summary>
	/// Tests the PythonDesignerGenerator inserts an event handler
	/// into the document correctly.
	/// </summary>
	[TestFixture]
	public class InsertNewEventHandlerTestFixture : InsertEventHandlerTestFixtureBase
	{
		public override void AfterSetUpFixture()
		{
			MockEventDescriptor mockEventDescriptor = new MockEventDescriptor("Click");
			insertedEventHandler = generator.InsertComponentEvent(null, mockEventDescriptor, "button1_click", String.Empty, out file, out position);
		}
		
		[Test]
		public void ExpectedCodeAfterEventHandlerInserted()
		{
			string expectedCode = GetTextEditorCode();			
			string eventHandler = "\tdef button1_click(self, sender, e):\r\n" +
								"\t\tpass";
			expectedCode = expectedCode + "\r\n" + eventHandler;
			
			Assert.AreEqual(expectedCode, viewContent.DesignerCodeFileContent);
		}
		
		/// <summary>
		/// Note that the text editor code already has the
		/// statement: 
		/// 
		/// "self._button1.Click += button1_click"
		/// 
		/// This is generated by the form designer framework and not
		/// by the designer generator.
		/// </summary>
		protected override string GetTextEditorCode()
		{
			return "from System.Windows.Forms import Form\r\n" +
					"\r\n" +
					"class MainForm(Form):\r\n" +
					"\tdef __init__(self):\r\n" +
					"\t\tself.InitializeComponents()\r\n" +
					"\t\r\n" +
					"\tdef InitializeComponents(self):\r\n" +
					"\t\tself._button1 = System.Windows.Forms.Button()\r\n" +
					"\t\tself.Controls.Add(self._button1)\r\n";
		}
		
		/// <summary>
		/// The generator should call the FormDesignerViewContent's
		/// MergeFormChanges method to make sure the latest version of the
		/// code is in the text editor.
		/// </summary>
		[Test]
		public void MergeFormChangesCalled()
		{
			Assert.IsTrue(viewContent.MergeFormChangesCalled);
		}
		
		[Test]
		public void InsertedEventHandlerReturnedTrue()
		{
			Assert.IsTrue(insertedEventHandler);
		}
		
		[Test]
		public void PositionEventHandlerInserted()
		{
			// The position is actually a line number. So 
			// it should be set to line 11.
			Assert.AreEqual(11, position);
		}
		
		[Test]
		public void FileNameSameAsDocumentFileName()
		{
			Assert.AreEqual(viewContent.DesignerCodeFile.FileName.ToString(), file);
		}
	}
}
