﻿// Copyright (c) AlphaSierraPapa for the SharpDevelop Team (for details please see \doc\copyright.txt)
// This code is distributed under the GNU LGPL (for details please see \doc\license.txt)

using System;
using ICSharpCode.WixBinding;
using NUnit.Framework;
using WixBinding.Tests.Utils;

namespace WixBinding.Tests.PackageFiles
{
	[TestFixture]
	public class ActiveViewChangedWhenPackageFilesViewOpenTestFixture : ActiveViewChangedWhenPackageFilesOpenTestFixtureBase
	{
		protected override void AfterInit()
		{
			// User switches to text editor with WiX document that we are currently showing
			// in the PackageFilesView.
			workbench.ActiveViewContent = viewWithOpenWixDocument;
			workbench.RaiseActiveViewContentChangedEvent();
		}
		
		[Test]
		public void CheckThatWixDocumentWindowIsActiveReturnsTrueForWixDocumentUsedWhenSettingUpTest()
		{
			WixDocumentWindow window = new WixDocumentWindow(workbench);
			Assert.IsTrue(window.IsActive(document));
		}
		
		[Test]
		public void PackageFilesControlShowFilesMethodCalledWhenUserSwitchesBackToPackageFilesViewWindow()
		{
			workbench.ActiveViewContent = packageFilesView;
			workbench.RaiseActiveViewContentChangedEvent();
			
			Assert.AreEqual(project, packageFilesControl.ShowFilesMethodProjectParameter);
		}
		
		[Test]
		public void PackageFilesControlsShowFilesNotInitiallyCalled()
		{
			Assert.IsNull(packageFilesControl.ShowFilesMethodProjectParameter);
		}
		
		[Test]
		public void PackageFilesControlShowFilesMethodIsNotCalledAfterPackageFilesViewIsDisposed()
		{
			workbench.ActiveViewContent = packageFilesView;
			packageFilesView.Dispose();
			workbench.RaiseActiveViewContentChangedEvent();
			
			Assert.IsNull(packageFilesControl.ShowFilesMethodProjectParameter);
		}
	}
}
